# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"MAD": "00_stats.ipynb",
         "Tukey": "00_stats.ipynb",
         "factory_atype": "01_timeseries.ipynb",
         "moving_average": "01_timeseries.ipynb",
         "moving_average_score": "01_timeseries.ipynb",
         "twitter": "01_timeseries.ipynb",
         "twitter_score": "01_timeseries.ipynb"}

modules = ["stats.py",
           "timeseries.py"]

doc_url = "https://fillipedem.github.io/pyanomaly/"

git_url = "https://github.com/fillipedem/pyanomaly/tree/master/"

def custom_doc_links(name): return None
